# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import survey_survey
from . import survey_user
from . import hr_resume_line
